@@ -3,11 +3,10 @@
 
 import time
 import board
-from busio import I2C
 import adafruit_bme680
 
-# Create library object using our Bus I2C port
-i2c = I2C(board.SCL, board.SDA)
+# Create sensor object, communicating over the board's default I2C bus
+i2c = board.I2C()  # uses board.SCL and board.SDA
 bme680 = adafruit_bme680.Adafruit_BME680_I2C(i2c, debug=False)
 
 # change this to match the location's pressure (hPa) at sea level
